@@ -79,6 +79,13 @@ def _parse_query_to_pandas(http_response_text):
     return df
 
 
+def _get_query_url(server_number, ticker, params):
+    return (
+        f"https://query1.finance.yahoo.com/v8/finance/chart/{ticker}?"
+        f"{urllib.parse.urlencode(params)}"
+    )
+
+
 def yahoo_historical_data(ticker="", from_date=0, to_date=0, yahoo_session=None):
     """
     Downloads historical end of day values for a single ticker and returns
@@ -180,10 +187,7 @@ def yahoo_historical_data(ticker="", from_date=0, to_date=0, yahoo_session=None)
     }
 
     # Sending the GET request, first on query1 server, if fail, on query2:
-    url = (
-        f"https://query1.finance.yahoo.com/v8/finance/chart/{ticker}?"
-        f"{urllib.parse.urlencode(params)}"
-    )
+    url = _get_query_url(1, ticker, params)
     logger.debug(f"Sending requests GET {url}")
     try:
         response = requests.get(url, cookies=cookies)
@@ -195,10 +199,7 @@ def yahoo_historical_data(ticker="", from_date=0, to_date=0, yahoo_session=None)
             "Server query1 response was not 200. "
             "Sending the same requests to server https://query2"
         )
-        url = (
-            f"https://query2.finance.yahoo.com/v8/finance/chart/{ticker}?"
-            f"{urllib.parse.urlencode(params)}"
-        )
+        url = _get_query_url(2, ticker, params)
         response = requests.get(url, cookies=cookies)
         if response.status_code != 200:
             logger.debug(
