@@ -96,12 +96,10 @@ def _parse_query_to_pandas(json_response):
     return df
 
 
-def _get_query_response(params, headers, encoded_body):
+def _get_query_response(params, headers, body):
     """Sending the GET request, first on query1 server, if fail, on query2."""
-    url = (
-        f"https://query1.finance.yahoo.com/v1/finance/screener?"
-        f"{urllib.parse.urlencode(params)}"
-    )
+    encoded_body = json.dumps(body).encode("UTF-8")
+    url = _get_query_url(1, params)
     logger.debug(f"Sending requests POST {url}")
     response = requests.post(url, headers=headers, data=encoded_body)
     if response.status_code == 200:
@@ -110,10 +108,7 @@ def _get_query_response(params, headers, encoded_body):
         f"Server query1 response was {response.status_code} (not 200). "
         f"Sending the same requests to server https://query2"
     )
-    url = (
-        f"https://query2.finance.yahoo.com/v1/finance/screener?"
-        f"{urllib.parse.urlencode(params)}"
-    )
+    url = _get_query_url(2, params)
     response = requests.post(url, headers=headers, data=encoded_body)
     if response.status_code == 200:
         return response
@@ -124,6 +119,13 @@ def _get_query_response(params, headers, encoded_body):
     return None
 
 
+def _get_query_url(server_number, params):
+    return (
+        f"https://query1.finance.yahoo.com/v1/finance/screener?"
+        f"{urllib.parse.urlencode(params)}"
+    )
+
+
 def yahoo_equity_screener(region="France", session=None):
     """
     Downloads live (or delayed) equities data given a region. This function
@@ -209,6 +211,8 @@ def yahoo_equity_screener(region="France", session=None):
         [200 rows x 4 columns]
     """
 
+    if region is None:
+        return pandas.DataFrame()
     if not isinstance(region, str):
         logger.warning(
             f"Parameter region={region}, type={type(region)} must "
@@ -278,10 +282,9 @@ def yahoo_equity_screener(region="France", session=None):
         "userId": "",
         "userIdType": "guid",
     }
-    encoded_body = json.dumps(body).encode("UTF-8")
 
     # POST request on both query servers:
-    response = _get_query_response(params, headers, encoded_body)
+    response = _get_query_response(params, headers, body)
     if response is None:
         return pandas.DataFrame()
 
@@ -298,14 +301,14 @@ def yahoo_equity_screener(region="France", session=None):
     total = _json["finance"]["result"][0]["total"]  # Total number of equities
     body["offset"] = 0
     body["size"] = 100
-    encoded_body = json.dumps(body).encode("UTF-8")
+    # encoded_body = json.dumps(body).encode("UTF-8")
     logger.debug(f"Yahoo POST response says {total} are available.")
 
     # Looping to scrap all equities:
     df = pandas.DataFrame()
     while body["offset"] < total:
         # POST request on both query servers:
-        response = _get_query_response(params, headers, encoded_body)
+        response = _get_query_response(params, headers, body)
         # Parsing results:
         _json = json.loads(response.text)
         _df = _parse_query_to_pandas(_json)
